package com.brilliance.swift.mx2element.pacs008001;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2element.AbstractMx2ElementCreator;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.prowidesoftware.swift.model.mx.dic.ActiveOrHistoricCurrencyAndAmount;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.DocumentHelper;

import java.math.BigDecimal;
import java.util.*;

public class Mx2ElementPacs008001Creator extends AbstractMx2ElementCreator {
    @Override
    public Map<String, Object> buildElement() {
        return super.buildElement();
    }

    public Object buildChrgInfo() {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
            String bodyParentPath = parentElementMaps.get("CdtTrfTxInf");
            int chrgsInfCount = XmlUtil.getChildrenCount(document, bodyParentPath+".CdtTrfTxInf.ChrgsInf", null);
            if (chrgsInfCount > 0) {
                List<Map<String, Object>> list = new ArrayList<Map<String, Object>>();
                for (int i=0; i<chrgsInfCount; i++) {
                    String amt = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.ChrgsInf("+i+").Amt");
                    String ccy = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.ChrgsInf("+i+").Amt@Ccy");
                    if (StringUtil.isNotEmpty(ccy) && StringUtil.isNotEmpty(amt)) {
                        Map<String, Object> maps = new LinkedHashMap<String, Object>();
                        maps.put("ccy", ccy);
                        maps.put("amt", new BigDecimal(amt));
                        list.add(maps);
                    }
                }
                return list;
            } else {
                return null;
            }
        } catch (DocumentException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public Object buildRgltryRptg() {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
            String bodyParentPath = parentElementMaps.get("CdtTrfTxInf");
          //  List<String> list = new ArrayList<String>();
            List list=new ArrayList();
            int mxRegulatoryReportingCount = XmlUtil.getChildrenCount(document, bodyParentPath+".CdtTrfTxInf.RgltryRptg", null);
            if (mxRegulatoryReportingCount > 0) {
                for (int i=0; i<mxRegulatoryReportingCount; i++) {
                    Map map=new HashMap();
                    String  dbtCdtRptgIndValue= XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.RgltryRptg("+i+").DbtCdtRptgInd");
                    map.put("dbtCdtRptgIndValue",dbtCdtRptgIndValue);
                    String  nameValue= XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.RgltryRptg("+i+").Authrty.Nm");
                    Map authrtyMap=new HashMap();
                    authrtyMap.put("nm",nameValue);
                    map.put("authrty",authrtyMap);

                    int mxRegulatoryReportingDetailCount = XmlUtil.getChildrenCount(document,bodyParentPath+".CdtTrfTxInf.RgltryRptg("+i+").Dtls", null);
                    //对应Dtls标签的存储
                    List subList=new ArrayList();
                    //Dtls标签下的Map数据存储
                    Map subMap=new HashMap();

                    List infList=new ArrayList();
                    if (mxRegulatoryReportingDetailCount > 0) {
                        for (int j=0; j<mxRegulatoryReportingDetailCount; j++) {
                            //处理Dtls标签
                            int mxRegulatoryReportingDetailInfCount = XmlUtil.getChildrenCount(document,bodyParentPath+".CdtTrfTxInf.RgltryRptg("+i+").Dtls("+j+").Inf", null);
                           //处理Dtls标签下的Inf循环标签
                            if (mxRegulatoryReportingDetailInfCount > 0) {
                                for (int k=0; k<mxRegulatoryReportingDetailInfCount; k++) {
                                    String inf = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.RgltryRptg("+i+").Dtls("+j+").Inf("+k+")");
                                    //list.add(inf);
                                    infList.add(inf);
                                }
                            }
                            subMap.put("inf",infList);

                            //处理Dtls标签下的Tp循环标签
                            String tpValue = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.RgltryRptg("+i+").Dtls("+j+").Tp");
                            subMap.put("tp",tpValue);

                            //处理Dtls标签下的Dt循环标签
                            String dtValue = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.RgltryRptg("+i+").Dtls("+j+").Dt");
                            subMap.put("dt",dtValue);

                            //处理Dtls标签下的Ctry循环标签
                            String ctryValue = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.RgltryRptg("+i+").Dtls("+j+").Ctry");
                            subMap.put("ctry",ctryValue);

                            //处理Dtls标签下的Cd循环标签
                            String cdValue = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.RgltryRptg("+i+").Dtls("+j+").Cd");
                            subMap.put("cd",cdValue);

                            //处理Dtls标签下的Amt循环标签
                            String amtValue = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.RgltryRptg("+i+").Dtls("+j+").Amt");
                            String ccyValue=XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.RgltryRptg("+i+").Dtls("+j+").Amt@Ccy");
                            if(StringUtil.isNotEmpty(amtValue)&&StringUtil.isNotEmpty(ccyValue)) {
                                ActiveOrHistoricCurrencyAndAmount activeOrHistoricCurrencyAndAmount=new ActiveOrHistoricCurrencyAndAmount();
                                activeOrHistoricCurrencyAndAmount.setCcy(ccyValue);
                                activeOrHistoricCurrencyAndAmount.setValue(new BigDecimal(amtValue));
                                subMap.put("amt",activeOrHistoricCurrencyAndAmount);
                            }
                            subList.add(subMap);
                        }
                        map.put("dtls",subList);
                    }
                    list.add(map);
                }
            }
            if (list.size() > 0) {
                return list;
            } else {
                return null;
            }
        } catch (DocumentException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public Object buildRltdRmtInf() {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
            String bodyParentPath = parentElementMaps.get("CdtTrfTxInf");
            int rltdRmtInfCount = XmlUtil.getChildrenCount(document, bodyParentPath+".CdtTrfTxInf.RltdRmtInf", null);
            List<String> list = new ArrayList<String>();
            if (rltdRmtInfCount > 0) {
                for (int i=0; i<rltdRmtInfCount; i++) {
                    String rmtId = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.RltdRmtInf("+i+").RmtId");
                    if (StringUtil.isNotEmpty(rmtId)) {
                        list.add(rmtId);
                    }
                }
            }
            if (list.size() > 0) {
                return list;
            } else {
                return null;
            }
        } catch (DocumentException e) {
            throw new SwiftException(e.getMessage());
        }
    }

    public Object buildStrdAddtlRmtInf() {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
            String bodyParentPath = parentElementMaps.get("CdtTrfTxInf");
            List<String> list = new ArrayList<String>();
            int strdCount = XmlUtil.getChildrenCount(document, bodyParentPath+".CdtTrfTxInf.RmtInf.Strd", null);
            if (strdCount > 0) {
                for (int i=0; i<strdCount; i++) {
                    int addtlRmtInfCount = XmlUtil.getChildrenCount(document,bodyParentPath+".CdtTrfTxInf.RmtInf.Strd("+i+").AddtlRmtInf", null);
                    if (addtlRmtInfCount > 0) {
                        for (int j=0; j<addtlRmtInfCount; j++) {
                            String inf = XmlUtil.getXmlNodeValue(document, bodyParentPath+".CdtTrfTxInf.RmtInf.Strd("+i+").AddtlRmtInf("+j+")");
                            list.add(inf);
                        }
                    }
                }
            }
            if (list.size() > 0) {
                return list;
            } else {
                return null;
            }
        } catch (DocumentException e) {
            throw new SwiftException(e.getMessage());
        }
    }
}
