package com.brilliance.swift.mx2mt.mt110.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;
import java.util.List;

/**
 *
 */
public class Field50aGenerate extends AbstractMx2MtTagsGenerate {

    private static String name_50A = "50A";
    private static String name_50F = "50F";
    private static String name_50K = "50K";

    @Override
    public void tagGenerate() throws SwiftException {
        context.set(Mx2MtContextIdentifier.MX_TO_MT_ERROR_LOCATION, "Block4/50a");
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        int cheBIC = getXmlNodeCounts(bodyHdrParentElementName, document, "Chq.Pyer.Id.OrgId.AnyBIC");
        int chePyerAcct = getXmlNodeCounts(bodyHdrParentElementName, document, "Chq.PyerAcct");
        int chePyerPstCtry = getXmlNodeCounts(bodyHdrParentElementName, document, "Chq.Pyer.PstlAdr.Ctry");
        String payerPath = bodyHdrParentElementName + ".Chq.Pyer";
        String orgidOthr = getXmlNodeValue(bodyHdrParentElementName, document, "Chq.Pyer.Id.OrgId.Othr");
        String prvtidOthr = getXmlNodeValue(bodyHdrParentElementName, document, "Chq.Pyer.Id.PrvtId.Othr");
        int addressLineCount = getXmlNodeCounts(bodyHdrParentElementName, document, "Chq.Pyer.PstlAdr.AdrLine");
        String pstladrAdrline = "";
        int  pyerNm = getXmlNodeCounts(bodyHdrParentElementName, document, "Chq.Pyer.Nm");
        String account = "";
        String nameAddress = "";
        if (addressLineCount > 0){
            pstladrAdrline = getXmlNodeValue(bodyHdrParentElementName, document, "Chq.Pyer.PstlAdr.AdrLine(0)");
        }
        if (cheBIC > 0) {
            String bicCode = mx_to_mtAnyBIC(payerPath);
            if (chePyerAcct > 0){
                account = mx_to_mtAccount(bodyHdrParentElementName + ".Chq.PyerAcct");
                tags.add(new Tag(name_50A, account + Mx2MtConstants.NEW_LINE + bicCode));
            }else {
                tags.add(new Tag(name_50A, bicCode));
            }
        } else if (chePyerPstCtry > 0){
            nameAddress = mx_to_mtFATFNameAndAddress(payerPath);
            if (chePyerAcct > 0) {
                account = mx_to_mtAccount(bodyHdrParentElementName + ".Chq.PyerAcct");
            } else if (StringUtil.isNotEmpty(orgidOthr) || StringUtil.isNotEmpty(prvtidOthr)){
                account = mx_to_mtFATFIdentification(payerPath, false);
            }
            if (StringUtil.isNotEmpty(account) && account.length() > 35) {
                account = account.substring(0, 35);
            }
            if (StringUtil.isEmpty(account)) {
                account = "/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
            }
            tags.add(new Tag(name_50F, account + Mx2MtConstants.NEW_LINE + nameAddress));
        } else if (addressLineCount > 0 && !Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE.equals(pstladrAdrline)){
            boolean structuredAddressIndicator = mx_to_mtAddressLineType(payerPath);
            if (structuredAddressIndicator) {
                nameAddress = mx_to_mtFATFNameAndAddress2(payerPath);
                if (chePyerAcct > 0) {
                    account = mx_to_mtAccount(bodyHdrParentElementName + ".Chq.PyerAcct");
                } else if (StringUtil.isNotEmpty(orgidOthr) || StringUtil.isNotEmpty(prvtidOthr)){
                    account = mx_to_mtFATFIdentification(payerPath, true);
                }
                if (StringUtil.isNotEmpty(account) && account.length() > 35) {
                    account = account.substring(0, 35);
                }
                if (StringUtil.isEmpty(account)) {
                    account = "/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                }
                tags.add(new Tag(name_50F, account + Mx2MtConstants.NEW_LINE + nameAddress));
            } else {
                nameAddress = mx_to_mtPartyNameAndUnstructuredAddress(payerPath);
                if (chePyerAcct > 0){
                    account = mx_to_mtAccount(bodyHdrParentElementName + ".Chq.PyerAcct");
                    tags.add(new Tag(name_50K, account + Mx2MtConstants.NEW_LINE + nameAddress));
                }else {
                    tags.add(new Tag(name_50K, nameAddress));
                }
            }
        }else if (pyerNm > 0){
            nameAddress = mx_to_mtPartyNameAndUnstructuredAddress(payerPath);
            if (chePyerAcct > 0){
                account = mx_to_mtAccount(bodyHdrParentElementName + ".Chq.PyerAcct");
                tags.add(new Tag(name_50K, account + Mx2MtConstants.NEW_LINE + nameAddress));
            }else {
                tags.add(new Tag(name_50K, nameAddress));
            }
        }
    }
}
